# modem_ber_example.gnu : configuration for output plot

reset                       # reset
set xrange [-5:25]           # set plot range (x axis)
set yrange [1e-5:1]         # set plot range (y axis)
set logscale y              # set y axis as logarithmic
set format y '10^{%L}'      # set format for y axis
set size ratio 0.6          # set plot scale
set xlabel 'SNR [dB]'       # label for x axis
set ylabel 'BER'            # label for y axis
set grid xtics ytics        # set grid
set key top right nobox     # set legend position
set linetype 1

# generate curve for theoretical BPSK and QPSK curves
snr(x)      = 10**(x/10)                        # linear SNR value
Q(x)        = 0.5*(1 - erf(x/sqrt(2)))          # Q function
BER_BPSK(x) = Q(sqrt(2*snr(x))          )       # BER for BPSK
BER_QPSK(x) = Q(sqrt(  snr(x))          )       # BER for QPSK
BER_8PSK(x) = Q(sqrt(2*snr(x))*sin(pi/8))*2./3. # BER for 8-PSK (approx.)
BER_16QAM(x) = 0.75*Q(sqrt(snr(x)/5)) + 0.5*Q(3*sqrt(snr(x)/5)) - 0.25*Q(5*sqrt(snr(x)/5))

# plot data using the first (SNR) and fourth (BER) columns
plot \
  BER_BPSK(x)  with lp pt 7 ps 0.4 lt 1 lw 1 lc rgb '#88ccaa' title 'BPSK (theory)',\
  BER_QPSK(x)  with lp pt 7 ps 0.4 lt 1 lw 1 lc rgb '#88aacc' title 'QPSK (theory)',\
  BER_8PSK(x)  with lp pt 7 ps 0.4 lt 1 lw 1 lc rgb '#aaaa88' title '8-PSK (theory, approx)',\
  BER_16QAM(x) with lp pt 7 ps 0.4 lt 1 lw 1 lc rgb '#aacc88' title '16-QAM (theory)',\
  'modem_ber_example.dat' u 1:4 with lp pt 7 ps 0.8 lt 1 lw 1 lc rgb '#004080' title 'Simulation'

